/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __UTILS_H__
#define __UTILS_H__

#include <string>
#include <vector>
#include <functional>
#include <map>

#ifndef PATH_SEPARATOR
#define PATH_SEPARATOR '/'
#endif

bool iCompare(const std::string& a, const std::string& b);
bool iCompare(const std::string& a, int aOffset, const std::string& b, int bOffset, int length);
bool isManagedAssembly(const std::string& fileName);
bool isNativeImage(const std::string& fileName);
std::string readSelfPath();
std::string concatPath(const std::string& path1, const std::string& path2);
void appendPath(std::string& path1, const std::string& path2);
std::string absolutePath(const std::string& path);
std::string baseName(const std::string& path);
bool endWithIgnoreCase(const std::string& str1, const std::string& str2, std::string& fileName);
void assembliesInDirectory(const std::vector<std::string>& directories, std::string& tpaList);

bool fileNotExist(const std::string& path);
std::string joinStrings(const std::vector<std::string>& strings, const char* const delimeter);

typedef std::function<void (const char*, const char*)> FileReader;
void scanFilesInDir(const char* directory, FileReader reader, unsigned int depth);
#endif /* __UTILS_H__ */
